pub struct VertexId(pub VertexIdType);Expand description
Vertex ID component.
Tuple Fields
0: VertexIdTypeTrait Implementations
Sourceimpl Component for VertexId
impl Component for VertexId
Sourceconst STORAGE_TYPE: StorageType = bevy::ecs::component::StorageType::Table
const STORAGE_TYPE: StorageType = bevy::ecs::component::StorageType::Table
A constant indicating the storage type used for this component.
fn register_component_hooks(_hooks: &mut ComponentHooks)
fn register_component_hooks(_hooks: &mut ComponentHooks)
Called when registering this component, allowing mutable access to its [
ComponentHooks].Auto Trait Implementations
impl Freeze for VertexId
impl RefUnwindSafe for VertexId
impl Send for VertexId
impl Sync for VertexId
impl Unpin for VertexId
impl UnsafeUnpin for VertexId
impl UnwindSafe for VertexId